package config

type OSSConfig struct {
	AccessKeyID     string `mapstructure:"access_key_id"`
	AccessKeySecret string `mapstructure:"access_key_secret"`
	Endpoint        string `mapstructure:"endpoint"`
	BucketName      string `mapstructure:"bucket_name"`
	PhotoFolder     string `mapstructure:"photo_folder"`
	LogLevel        string `mapstructure:"log_level"`
	HostURL         string `mapstructure:"host_url"`
	PublicURL       string `mapstructure:"public_url"`
}

func (c OSSConfig) GetAccessKeyID() string {
	return c.AccessKeyID
}

func (c OSSConfig) GetAccessKeySecret() string {
	return c.AccessKeySecret
}

func (c OSSConfig) GetEndpoint() string {
	return c.Endpoint
}

func (c OSSConfig) GetBucketName() string {
	return c.BucketName
}

func (c OSSConfig) GetLogLevel() string {
	return c.LogLevel
}

func (c OSSConfig) GetHostURL() string {
	return c.HostURL
}

func (c OSSConfig) GetPublicURL() string {
	return c.PublicURL
}

func (c OSSConfig) GetPhotoFolder() string {
	return c.PhotoFolder
}
